@@ -27,7 +27,7 @@ class IRExecHandler(ProgramHandler):
     def __init__(self,lircd, lircrc,repeat,delay):
         application_name="irexec"
         application_dictionary={ \
-            "power,clear":"killall mythfrontend.real && mythfrontend --service &", \
+            "power,clear":"(kill $(pgrep mythfrontend) || true) && mythfrontend --service &", \
         }
         ProgramHandler.__init__(self,application_name,application_dictionary,lircd,lircrc,repeat,delay)
 
